@@ -1,4 +1,4 @@
-/*  $Id: perl.c 9247 2011-07-17 18:03:49Z iulius $
+/*  $Id: perl.c 10229 2018-01-28 21:21:21Z iulius $
 **
 **  Embedded Perl support for INN.
 **
@@ -23,7 +23,9 @@
 #include "inn/libinn.h"
 
 #include <EXTERN.h>
+#pragma GCC diagnostic ignored "-Wredundant-decls"
 #include <perl.h>
+#pragma GCC diagnostic warning "-Wredundant-decls"
 #include <XSUB.h>
 #include "ppport.h"
 
@@ -66,6 +68,7 @@ PerlFilter(bool value)
 {
     dSP;
     char *argv[] = { NULL };
+    SV *errsv;
 
     if (value == PerlFilterActive)
         return true;
@@ -78,9 +81,10 @@ PerlFilter(bool value)
             /* No need for PUSHMARK(SP) with call_argv(). */
             perl_call_argv("filter_end", G_EVAL | G_DISCARD | G_NOARGS, argv);
             SPAGAIN;
-            if (SvTRUE(ERRSV)) {
+            errsv = ERRSV;
+            if (SvTRUE(errsv)) {
                 syslog (L_ERROR, "SERVER perl function filter_end died: %s",
-                        SvPV(ERRSV, PL_na));
+                        SvPV(errsv, PL_na));
                 (void) POPs;
             }
             PUTBACK;
@@ -133,6 +137,7 @@ void PERLsetup (char *startupfile, char *filterfile, const char *function)
     if (startupfile != NULL && filterfile != NULL) {
         char *evalfile = NULL;
         bool failure;
+        SV *errsv;
         dSP;
 
         ENTER;
@@ -153,10 +158,11 @@ void PERLsetup (char *startupfile, char *filterfile, const char *function)
         evalfile = NULL;
 
         /* Check $@. */
-        if (SvTRUE(ERRSV)) {
+        errsv = ERRSV;
+        if (SvTRUE(errsv)) {
             failure = true;
             syslog(L_ERROR,"SERVER perl loading %s failed: %s",
-                   startupfile, SvPV(ERRSV, PL_na));
+                   startupfile, SvPV(errsv, PL_na));
         } else {
             failure = false;
         }
@@ -187,6 +193,7 @@ int PERLreadfilter(char *filterfile, const char *function)
     char *argv[] = { NULL };
     char *evalfile = NULL;
     bool failure;
+    SV *errsv;
 
     if (perl_get_cv("filter_before_reload", false) != NULL) {
         ENTER;
@@ -195,10 +202,11 @@ int PERLreadfilter(char *filterfile, const char *function)
         perl_call_argv("filter_before_reload", G_EVAL|G_DISCARD|G_NOARGS, argv);
         SPAGAIN;
         /* Check $@. */
-        if (SvTRUE(ERRSV)) {
+        errsv = ERRSV;
+        if (SvTRUE(errsv)) {
             failure = true;
             syslog (L_ERROR,"SERVER perl function filter_before_reload died: %s",
-                    SvPV(ERRSV, PL_na));
+                    SvPV(errsv, PL_na));
             (void)POPs;
         } else {
             failure = false;
@@ -228,10 +236,11 @@ int PERLreadfilter(char *filterfile, const char *function)
     evalfile = NULL;
 
     /* Check $@. */
-    if (SvTRUE(ERRSV)) {
+    errsv = ERRSV;
+    if (SvTRUE(errsv)) {
         failure = true;
         syslog (L_ERROR,"SERVER perl loading %s failed: %s",
-                filterfile, SvPV(ERRSV, PL_na));
+                filterfile, SvPV(errsv, PL_na));
     } else {
         failure = false;
     }
@@ -258,9 +267,10 @@ int PERLreadfilter(char *filterfile, const char *function)
         evalfile = NULL;
 
         /* Check $@. */
-        if (SvTRUE(ERRSV)) {
+        errsv = ERRSV;
+        if (SvTRUE(errsv)) {
             syslog (L_ERROR,"SERVER perl undef &%s failed: %s",
-                    function, SvPV(ERRSV, PL_na)) ;
+                    function, SvPV(errsv, PL_na)) ;
         }
         PUTBACK;
         FREETMPS;
@@ -276,10 +286,11 @@ int PERLreadfilter(char *filterfile, const char *function)
         perl_call_argv("filter_after_reload", G_EVAL|G_DISCARD|G_NOARGS, argv);
         SPAGAIN;
         /* Check $@. */
-        if (SvTRUE(ERRSV)) {
+        errsv = ERRSV;
+        if (SvTRUE(errsv)) {
             failure = true;
             syslog (L_ERROR,"SERVER perl function filter_after_reload died: %s",
-                    SvPV(ERRSV, PL_na));
+                    SvPV(errsv, PL_na));
             (void)POPs;
         } else {
             failure = false;
@@ -419,7 +430,6 @@ XS(XS_INN_syslog)
     logmsg = (const char *) SvPV(ST(1), PL_na);
 
     switch (*loglevel) {
-        default:                priority = LOG_NOTICE;
         case 'a': case 'A':     priority = LOG_ALERT;           break;
         case 'c': case 'C':     priority = LOG_CRIT;            break;
         case 'e': case 'E':     priority = LOG_ERR;             break;
@@ -427,6 +437,7 @@ XS(XS_INN_syslog)
         case 'n': case 'N':     priority = LOG_NOTICE;          break;
         case 'i': case 'I':     priority = LOG_INFO;            break;
         case 'd': case 'D':     priority = LOG_DEBUG;           break;
+        default:                priority = LOG_NOTICE;
     }
     syslog(priority, "filter: %s", logmsg);
     XSRETURN_UNDEF;
